==> haskell-either-5.0.2-114-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-either.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 either
version:              5.0.2
visibility:           public
id:                   either-5.0.2-3iPCKd8i7QV1efbiqGSNOO
key:                  either-5.0.2-3iPCKd8i7QV1efbiqGSNOO
license:              BSD-3-Clause
copyright:            Copyright (C) 2008-2017 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/either/
synopsis:             Combinators for working with sums
description:          Combinators for working with sums.
category:             Control, Monads
abi:                  8c409f4506c62e32f282463e0ac51f7b
exposed:              True
exposed-modules:      Data.Either.Combinators Data.Either.Validation
import-dirs:          /usr/lib/ghc-9.2.8/site-local/either-5.0.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/either-5.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-either
hs-libraries:         HSeither-5.0.2-3iPCKd8i7QV1efbiqGSNOO
depends:
    base-4.16.4.0 bifunctors-5.6-ADEUrWrknc28U7HKfVMzZQ mtl-2.2.2
    profunctors-5.6.2-IwG4rHL6atH4Ka7pLrv2VH
    semigroupoids-5.3.7-8VadR23YqgWJtKdu0uOLHe

haddock-interfaces:   /usr/share/doc/haskell-either/html/either.haddock
haddock-html:         /usr/share/doc/haskell-either/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-either-5.0.2-123-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-either.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 either
version:              5.0.2
visibility:           public
id:                   either-5.0.2-JzPN0vV29iV3RTvF7knmvB
key:                  either-5.0.2-JzPN0vV29iV3RTvF7knmvB
license:              BSD-3-Clause
copyright:            Copyright (C) 2008-2017 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/either/
synopsis:             Combinators for working with sums
description:          Combinators for working with sums.
category:             Control, Monads
abi:                  1845e0e5ecfe091532631c2e4aa2d844
exposed:              True
exposed-modules:      Data.Either.Combinators Data.Either.Validation
import-dirs:          /usr/lib/ghc-9.2.8/site-local/either-5.0.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/either-5.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-either
hs-libraries:         HSeither-5.0.2-JzPN0vV29iV3RTvF7knmvB
depends:
    base-4.16.4.0 bifunctors-5.6-Bb9FnxojxnmAAd961eYGAf mtl-2.2.2
    profunctors-5.6.2-FWe4PQU8eE3GeDqm3R4ckm
    semigroupoids-5.3.7-3HMcZlsRlqoKaeVPumQFHg

haddock-interfaces:   /usr/share/doc/haskell-either/html/either.haddock
haddock-html:         /usr/share/doc/haskell-either/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
